@@ -10,6 +10,7 @@
 #define SCORE_DIALOG_H
 
 #include <QDialog>
+#include <QMainWindow>
 #include <QTableWidget>
 #include <QListWidget>
 #include <QComboBox>
@@ -23,45 +24,61 @@
 #endif
 
 #include "data.h"
+#include "table-model.h"
+
+class ScoreWindow: public QMainWindow
+{
+    Q_OBJECT;
+
+public:
+    ScoreWindow(QWidget *parent = 0);
+    ~ScoreWindow();
+
+    void setup(Score * score, Course * course);
+
+private:
+    ScoreTableModel *model;
+};
+
 
 class SelectDialog: public QDialog
 {
-  Q_OBJECT
+    Q_OBJECT;
 
- public:
-  SelectDialog(QWidget *parent = 0);
-
-  void results(QString &club, QString &course, QString &date);
-  void init(QList<Club *> &list);
+public:
+    SelectDialog(QWidget *parent = 0);
+    
+    void results(QString &club, QString &course, QString &date);
+    void init(QList<Club *> &list);
 
 private slots:
-  void next(void);
+    void next(void);
 
- private:
+private:
 
-  bool validate(void);
-  void reject(void);
+    bool validate(void);
+    void reject(void);
 
-  void comboBoxCourseUpdate(void);
-  void createLayout(QWidget *parent = 0);
+    void comboBoxCourseUpdate(void);
+    void createLayout(QWidget *parent = 0);
 
-  // Widgets
-  QListWidget  *listClub;
+    // Widgets
+    QListWidget  *listClub;
 #ifdef Q_WS_MAEMO_5
-  QMaemo5ValueButton *dateButton;
+    QMaemo5ValueButton *dateButton;
 #else
-  QLineEdit    *lineEditDate;
-  QDateEdit    *date;
+    QLineEdit    *lineEditDate;
+    QDateEdit    *date;
 #endif
-  QLabel       *labelClub;
-  QLabel       *labelCourse;
-  QPushButton  *pushButtonNext;
+    QLabel       *labelClub;
+    QLabel       *labelCourse;
+    QPushButton  *pushButtonNext;
 
   // Layouts
-  QVBoxLayout *leftLayout;
-  QVBoxLayout *rightLayout;
+    QVBoxLayout *leftLayout;
+    QVBoxLayout *rightLayout;
 
-  QList<Club *> clubList;
+    QList<Club *> clubList;
 };
 
 class ScoreDialog: public QDialog
@@ -70,6 +87,7 @@ class ScoreDialog: public QDialog
 
 public:
   ScoreDialog(QWidget *parent = 0);
+  ~ScoreDialog();
   void init(Course *course, Score *score = 0);
   void results(QVector<QString> &scores);
   bool validate(void);
